"use strict";

/* exported logger */

var Panel = require('../Panel');

var Functions = require('../../Functions');
var logger = require('../../logger');

var Promise = require("bluebird");

function CommentsAdminPanel(params) {
  params.scrollable = true;
  Panel.call(this, params);

  this._createGui();
}

CommentsAdminPanel.prototype = Object.create(Panel.prototype);
CommentsAdminPanel.prototype.constructor = CommentsAdminPanel;

CommentsAdminPanel.prototype._createGui = function() {
  var self = this;
  var projectsDiv = Functions.createElement({
    type : "div",
  });
  self.getElement().appendChild(projectsDiv);

  var dataDiv = Functions.createElement({
    type : "div",
    style : "display:table",
  });
  projectsDiv.appendChild(dataDiv);

  var commentsCell = Functions.createElement({
    type : "div",
    style : "display:table-cell;width:100%;vertical-align:top",
  });
  projectsDiv.appendChild(commentsCell);

  var commentsTable = Functions.createElement({
    type : "table",
    name : "commentsTable",
    className : "display",
    style : "width:100%",
  });
  commentsCell.appendChild(commentsTable);

  $(commentsTable).DataTable({
    columns : [ {
      title : 'Id',
    }, {
      title : 'Title',
    }, {
      title : 'Author',
    }, {
      title : 'Email',
    }, {
      title : 'Content',
    }, {
      title : 'Removed',
    }, {
      title : 'Pinned',
    }, ],
  });

  var projectsCell = Functions.createElement({
    type : "div",
    style : "display:table-cell",
  });
  projectsDiv.appendChild(projectsCell);

  var selectProject = Functions.createElement({
    type : "select",
    name : "projectSelect",
  });
  selectProject.size = "12";
  selectProject.onchange = function() {
    return self.onProjectChange();
  };

  projectsCell.appendChild(Functions.createElement({
    type : "h3",
    content : "Project",
  }));
  projectsCell.appendChild(selectProject);
}

CommentsAdminPanel.prototype.init = function() {
  var self = this;
  return self.refreshProjects();
};

CommentsAdminPanel.prototype.refreshProjects = function() {
  var self = this;
  var projectSelect = $("[name='projectSelect']", self.getElement())[0];
  return ServerConnector.getProjects().then(function(projects) {
    while (projectSelect.firstChild) {
      projectSelect.removeChild(projectSelect.firstChild);
    }
    projects.sort(function(project1, project2) {
      if (project1.getProjectId() < project2.getProjectId()) {
        return -1;
      } else if (project1.getProjectId() > project2.getProjectId()) {
        return 1;
      } else {
        return 0;
      }
    });

    for (var i = 0; i < projects.length; i++) {
      var project = projects[i];
      var value = project.getProjectId();
      var name = project.getProjectId() + " - " + project.getName();
      projectSelect.appendChild(new Option(name, value));
    }
    return ServerConnector.getProjectId();
  }).then(function(projectId) {
    projectSelect.value = projectId;
    return self.onProjectChange();
  }).then(function() {
    $(window).trigger('resize');
  });
};

CommentsAdminPanel.prototype.getSelectedProjectId = function() {
  var projectSelect = $("[name='projectSelect']", this.getElement())[0];
  return projectSelect.value;
};

CommentsAdminPanel.prototype.onProjectChange = function() {
  var self = this;

  return ServerConnector.getComments({
    projectId : self.getSelectedProjectId(),
  }).then(function(comments) {
    var dataTable = $($("[name='commentsTable']", self.getElement())[0]).DataTable();
    var data = [];
    for (var i = 0; i < comments.length; i++) {
      data.push(self.commentToTableRow(comments[i]));
    }
    dataTable.clear().rows.add(data).draw();
    $("[name='commentsTable']", self.getElement()).on("click", "[name='removeComment']", function() {
      var button = this;
      return ServerConnector.removeComment({
        commentId : $(button).attr("data")
      }).then(function() {
        $(button).after("<span>YES</span>");
        button.style.display = "none";
      });
    });
  });
};

CommentsAdminPanel.prototype.commentToTableRow = function(comment) {
  var self = this;
  var projectId = self.getSelectedProjectId();
  var toYesNo = function(val) {
    if (val) {
      return "YES";
    } else {
      return "NO";
    }
  };
  var title = null;
  if (!comment.isRemoved()) {
    var commentLink = "index.xhtml?id=" + projectId + // 
    "&x=" + comment.getCoordinates().x + // 
    "&y=" + comment.getCoordinates().y + // 
    "&zoom=12" + //
    "&comments=on";
    title = "<a href='" + commentLink + "' target='" + projectId + "'>" + comment.getTitle() + "</a>";
  } else {
    title = comment.getTitle();
  }

  var remove = null;
  if (comment.isRemoved()) {
    remove = "YES";
  } else {
    remove = "<button name='removeComment' data='" + comment.getId() + "'>REMOVE</button>";
  }

  var row = [ comment.getId(), // 
  title, //
  comment.getAuthor(), // 
  comment.getEmail(), // 
  comment.getContent(), // 
  remove, //
  toYesNo(comment.isPinned()) ];
  return row;
}

module.exports = CommentsAdminPanel;
